%define _disable_ld_no_undefined 1

# Set to 1 to use system scirenderer instead of bundle's one
%define with_system_scirenderer 1

# baserelease defines which build revision of this version we're building.
# The magical name baserelease is matched by the rpmdev-bumpspec tool, which
# you should use.
%global baserelease 1
%define rel 1

# On a released (stable or beta) version set it to 1
%global is_release 1
# On a stable version set it to 1
%global is_stable 1

# On a pre-release packages set this to the selected name
%global prerelease_name beta-2

# On a snapshot packages set this to the selected date and commit.
%global prerelease_date 20161209
%global prerelease_timestamp 1481215650

# pkg_release is what we'll fill in for the rpm Release: field
%if %{is_release}
    %if %{is_stable}
        # stable release
        %global pkg_release %mkrel %{rel}
    %else
        # alpha or beta release
        %global escaped_prerelease_name %(echo %{prerelease_name} |tr -cd [:alnum:])
        %global pkg_release %mkrel 0.%{baserelease}.%{escaped_prerelease_name}.%{rel}
    %endif
%else
    # nightly build
    %global pkg_release %mkrel 0.%{baserelease}.%{prerelease_date}snap.%{rel}
%endif

Name:           scilab
Version:        6.0.0
Release:        %{pkg_release}
Summary:        Scientific software package for numerical computations

Group:          Sciences/Mathematics
License:        CeCILL
URL:            http://www.scilab.org/
%if %{is_release}
    %if %{is_stable}
        # stable release
Source0:        http://www.scilab.org/download/%{version}/scilab-%{version}-src.tar.gz
    %else
        # alpha or beta release
Source0:        http://www.scilab.org/download/%{version}-%{prerelease_name}/scilab-%{version}-%{prerelease_name}-src.tar.gz
    %endif
%else
    # nightly build
Source0:        http://downloadarea.scilab.org/download/%(date -d%{prerelease_date} +%%Y-%%m-%%d)/scilab-master-%{prerelease_timestamp}-src.tar.gz
%endif

# Bug 767102 - help() should suggest scilab-doc
Patch1:         %{name}-0001-Use-pkcon-to-install-doc-package.patch
# Update to the latest JOGL version
# see https://codereview.scilab.org/#/c/17530/
Patch2:         %{name}-0002-jogl-2.3.2.patch
# Dependencies are extracted from :
# "http://wiki.scilab.org/Dependencies of Scilab 5.X"
# Add support for ppc64le
Patch3:         %{name}-0003-fix-ppc64le-build.patch

#fix std::isnan() to isnan() and std::isfinite() to finite()
Patch10:        %{name}-6.0.0-isnan-and-isfinite.patch

#lapack function dgeqpf is obsolete and has been replace by dgeqp3
Patch11:        %{name}-6.0.0-dgeqpf.patch

# Mandatory
BuildRequires:  gcc-gfortran

## for dynamic link features
Requires:       gcc
Requires:       gcc-c++
Requires:       gcc-gfortran

# Core
BuildRequires:  libxml2-devel
BuildRequires:  pcre-devel
BuildRequires:  ncurses-devel
BuildRequires:  libcurl-devel
BuildRequires:  eigen3-devel

# Numerical libraries
# see "http://wiki.scilab.org/Linalg performances"
# TBD Packaging guidelines https://fedorahosted.org/fpc/ticket/352
BuildRequires:  lapack-devel
BuildRequires:  arpack-devel

# GUI/Console
BuildRequires:  jpackage-utils
BuildRequires:  java-devel
BuildRequires:  ant

BuildRequires:  flexdock
BuildRequires:  jogl2
BuildRequires:  mesagl-devel
BuildRequires:  pkgconfig(libpcreposix)

Requires:       flexdock
Requires:       jogl2

BuildRequires:  jrosetta
Requires:       jrosetta

BuildRequires:  apache-commons-logging
BuildRequires:  javahelp2
BuildRequires:  jlatexmath
BuildRequires:  jlatexmath-fop
BuildRequires:  jgraphx
BuildRequires:  lucene
BuildRequires:  lucene-analysis
BuildRequires:  lucene-queryparser
BuildRequires:  fop
BuildRequires:  jeuclid
BuildRequires:  batik
BuildRequires:  xmlgraphics-commons
BuildRequires:  ecj

Requires:       apache-commons-logging
Requires:       javahelp2
Requires:       jlatexmath
Requires:       jlatexmath-fop
Requires:       jgraphx
Requires:       fop
Requires:       jeuclid
Requires:       batik
Requires:       xmlgraphics-commons
Requires:       ecj
Requires:       bwidget

# TCL/TK features
BuildRequires:  tcl-devel
BuildRequires:  tk-devel

Requires:       tcl
Requires:       tk

# Modelica
BuildRequires:  ocaml

# Documentation
BuildRequires:  saxon
BuildRequires:  docbook-style-xsl
#BuildRequires:  liberation-sans-fonts
Requires:       saxon

# QA tests and validation
BuildRequires:  checkstyle
BuildRequires:  junit

# All optional dependencies are needed to provide a full-featured Scilab
BuildRequires:  gettext-devel
BuildRequires:  fftw-devel
BuildRequires:  matio-devel
BuildRequires:  suitesparse-devel
BuildRequires:  hdf5-devel

# hdf5 does not bump soname but check at runtime
Requires:       hdf5 = %{_hdf5_version}

# Specific dependencies for packaging purpose
BuildRequires:  desktop-file-utils
BuildRequires:  appstream-util

%if %{with_system_scirenderer}
# System scirenderer (available on Mageia)
BuildRequires:  scirenderer >= 1.1.0-8
Requires:       scirenderer >= 1.1.0-8
%endif

Recommends:     %{name}-doc

%description
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

%package devel
Group:          Development/Java
License:        CeCILL

Summary:        Scientific software package for numerical computations (include files)

Requires:       %{name} = %{version}-%{release}

%description devel
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provide include files for Scilab.

%package doc
Group:          Documentation
License:        CeCILL

Summary:        Scientific software package (documentation files)

BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description doc
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provide documentation, example and help files for Scilab.

%package tests
Group:          Sciences/Mathematics
License:        CeCILL

Summary:        Provides test files for Scilab

BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}
Requires:       testng

%description tests
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provide test files for Scilab.

%prep
%if %{is_release}
    %if %{is_stable}
%setup -q
    %else
%setup -q -n %{name}-%{version}-%{prerelease_name}
    %endif
%else
%setup -q -n %{name}-master-%{prerelease_timestamp}
%endif

%patch1 -p1 -b .pkgcon
%patch2 -p1 -b .jogl
%patch3 -p1 -b .ppc64le
%patch10 -p1 -b .isnan
%patch11 -p1 -b .dgeqpf

# Fix Class-Path in manifest
sed -i '/name="Class-Path"/d' build.incl.xml

# Fix file-not-utf8
iconv -f ISO_8859-1 -t UTF-8 COPYING >COPYING.utf8
mv COPYING.utf8 COPYING

# Rename if the builder's home exists
[ -d ~/.Scilab.before.build -a -d ~/.Scilab ] && rm -fr ~/.Scilab
[ -d ~/.Scilab ] && mv ~/.Scilab ~/.Scilab.before.build

%build
# disable-static-system-lib: do not static link with compiler libs
# without-emf: disabled because freehep-*.jar are not packaged in fedora and
#              it is a windows specific format
%configure2_5x \
  --disable-static-system-lib \
  --disable-rpath \
  --enable-shared \
  --without-emf \
  --with-modelica \
%if %{with_system_scirenderer}
  --with-external-scirenderer \
%endif
  --without-umfpack

%make_build
%make_build doc SCIVERBOSE=1

%install
%make_install
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
%find_lang %{name}

# Remove specific applications, user should use CLI options instead
rm -fr %{buildroot}%{_datadir}/applications/%{name}-*.desktop \
  %{buildroot}%{_datadir}/applications/scinotes.desktop \
  %{buildroot}%{_datadir}/applications/xcos.desktop
# Remove la files
rm -fr %{buildroot}%{_libdir}/%{name}/*.la

# Add localized help files to scilab-doc.lang
# adapted from find-lang.sh
# always provide the english help to handle missing localized help pages
find %{buildroot}%{_datadir}/%{name}/modules/helptools/jar -type f -o -type l|sed '
s:'"%{buildroot}"'::
s:\(.*/'"%{name}"'_\)\([^\._]\+\)\(.*\.jar$\):%lang(\2) \1\2\3:
s:^\([^%].*\)::
s:%lang(en) ::
s:%lang(C) ::
/^$/d' |tee %{name}-doc.lang

# Use the new ld.so.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
pushd %{buildroot}%{_sysconfdir}/ld.so.conf.d
echo "%{_libdir}/%{name}" > %{name}.conf
popd

%check
# disabled for alpha
make check-TESTS || true

%files -f %{name}.lang
%doc README.md ACKNOWLEDGEMENTS CHANGES.md COPYING COPYING-BSD
%{_sysconfdir}/ld.so.conf.d/*
%{_bindir}/*
%{_libdir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/appdata/*.appdata.xml
%{_datadir}/icons/*/*/*/*.png
%{_datadir}/mime/packages/%{name}.xml
# part of scilab-devel
%exclude %{_datadir}/%{name}/contrib
%exclude %{_datadir}/%{name}/tools
# part of scilab-doc
%exclude %{_datadir}/%{name}/modules/helptools/jar/*%{name}_*.jar
%exclude %{_datadir}/%{name}/modules/*/examples
%exclude %{_datadir}/%{name}/modules/*/help
%exclude %{_datadir}/%{name}/modules/*/javadoc
# part of scilab-tests
%exclude %{_datadir}/%{name}/modules/*/tests

%files devel
%doc README.md ACKNOWLEDGEMENTS CHANGES.md COPYING COPYING-BSD
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}/contrib
%{_datadir}/%{name}/tools

%files doc -f %{name}-doc.lang
%doc README.md ACKNOWLEDGEMENTS CHANGES.md COPYING COPYING-BSD
%{_datadir}/doc/%{name}-*
%{_datadir}/%{name}/modules/*/examples
%{_datadir}/%{name}/modules/*/help
%{_datadir}/%{name}/modules/*/javadoc

%files tests
%doc README.md ACKNOWLEDGEMENTS CHANGES.md COPYING COPYING-BSD
%{_datadir}/%{name}/modules/*/tests


%changelog
* Fri Feb 24 2017 daviddavid <daviddavid> 6.0.0-1.mga6
+ Revision: 1087755
- New version 6.0.0 Final

* Tue Jan 31 2017 barjac <barjac> 6.0.0-0.6.beta2.6.mga6
+ Revision: 1084305
- Rebuild for eigen3

* Wed Nov 30 2016 daviddavid <daviddavid> 6.0.0-0.6.beta2.5.mga6
+ Revision: 1071220
- use system scirenderer

* Tue Nov 29 2016 neoclust <neoclust> 6.0.0-0.6.beta2.4.mga6
+ Revision: 1070909
- Fix file list to build on arm

* Sat Nov 26 2016 daviddavid <daviddavid> 6.0.0-0.6.beta2.3.mga6
+ Revision: 1070258
- fix some hardcoded path (disable rpath, use the new ld.so.conf.d)
- requires saxon
- recommends scilab-doc

* Wed Nov 23 2016 eatdirt <eatdirt> 6.0.0-0.6.beta2.2.mga6
+ Revision: 1069511
- Adding patches to fix missing deps / build failure

  + neoclust <neoclust>
    - New version 6.0.0-beta

  + pterjan <pterjan>
    - Rebuild for fix in ocaml
    - quadmath is not available on arm

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Mon Oct 05 2015 daviddavid <daviddavid> 5.5.2-2.mga6
+ Revision: 886366
- rebuild for new tcl/tk 8.6.4

* Wed Aug 19 2015 ycantin <ycantin> 5.5.2-1.mga6
+ Revision: 865860
- new version 5.5.2
- disable jogl patch (no longer needed)

* Mon Jul 27 2015 daviddavid <daviddavid> 5.5.1-4.mga6
+ Revision: 858204
- add Patch4 to fix build with the latest batik
- add Patch5 from Fedora to fix build with the latest xmlgraphics-commons
- rebuild with new hdf5

* Wed Feb 18 2015 akien <akien> 5.5.1-3.mga5
+ Revision: 815580
- Add Debian patch to fix build with jogl 2.2

* Wed Nov 05 2014 tv <tv> 5.5.1-2.mga5
+ Revision: 795699
- Drop no longer needed BuildRequires on java-rpmbuild

* Mon Oct 20 2014 grenoya <grenoya> 5.5.1-1.mga5
+ Revision: 792182
- new version 5.5.1

* Wed Oct 15 2014 umeabot <umeabot> 5.5.0-4.mga5
+ Revision: 742066
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 5.5.0-3.mga5
+ Revision: 689057
- Mageia 5 Mass Rebuild

  + tv <tv>
    - use %%global for req/prov exclude
    - autoconvert to new prov/req excludes

* Fri Sep 05 2014 grenoya <grenoya> 5.5.0-2.mga5
+ Revision: 672273
- new version 5.5.0
- add patch for jdk8

* Mon Apr 14 2014 grenoya <grenoya> 5.5.0-1.mga5
+ Revision: 614163
- new version 5.5.0

* Fri Feb 07 2014 stormi <stormi> 5.5.0-0.beta1.4.mga5
+ Revision: 585557
- fix categories in desktop files (patch from AlexL)
- add russian translations in desktop files (patch from AlexL)

* Mon Dec 02 2013 grenoya <grenoya> 5.5.0-0.beta1.3.mga4
+ Revision: 554718
- fix require on suitesparse

* Sun Dec 01 2013 grenoya <grenoya> 5.5.0-0.beta1.2.mga4
+ Revision: 554577
- disable giws rebuild
- new version 5.4.1

  + umeabot <umeabot>
    - Mageia 4 Mass Rebuild

  + dmorgan <dmorgan>
    - Update to 5.5.0 beta1

* Sat Aug 03 2013 grenoya <grenoya> 5.4.0-2.mga4
+ Revision: 462993
- revert new version
- rebuild for new hdf5

  + fwang <fwang>
    - new version 5.4.1

* Wed Jan 16 2013 dmorgan <dmorgan> 5.4.0-2.mga3
+ Revision: 388778
- Appy patches
  Remove sed for jgraphx check
- Rebuild against new jhdf5
- Rebuild against new struts12

  + grenoya <grenoya>
    - finish spec file adaptation to new version
    - new version 5.4.0 (empty build)

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

  + fwang <fwang>
    - rebuild for new libamd and libumfpack

* Sun Dec 11 2011 eatdirt <eatdirt> 5.3.3-2.mga2
+ Revision: 180487
- Rebuilt for fftw-3.3

* Mon Oct 31 2011 grenoya <grenoya> 5.3.3-1.mga2
+ Revision: 160682
- add new patch(#8) due to nex version of fop which drop thingd already included in xmlgraphics-commons
- remove patch #5 not needed with actual java stack
- add patch #7 (hdf5 version restriction for xcos seems to be false)
- remove BuildConflict scilab (did not apply in mageia)
- convert BuildConflicts for junit and termcap-devel into BuildRequires (no harm done during build and no esplainations of why it was buildconflicts)

  + fwang <fwang>
    - drop .la files

  + tv <tv>
    - new release

* Tue Apr 26 2011 wally <wally> 5.3.0-2.mga1
+ Revision: 91824
- fix desktop file name (mga#954)
- drop buildroot definition

* Thu Apr 07 2011 grenoya <grenoya> 5.3.0-1.mga1
+ Revision: 81681
- clean old Mdv syntax
- add BuildConflicts with xmlgraphics-fop
- imported package scilab


* Thu Jan 27 2011 Paulo Andrade <pcpa@mandriva.com.br> 5.3.0-1mdv2011.0
+ Revision: 633296
- Enable scicos
- Update to scilab 5.3.0

* Sat Jul 31 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 5.2.2-3mdv2011.0
+ Revision: 564052
- Patch18: set java library path

* Tue May 18 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 5.2.2-2mdv2010.1
+ Revision: 545244
- Patch16: fix LD_PRELOAD paths
- Patch17: add more paths into the librarypath.xml file
- add requires on hdf-java for mdv > 2010.0

* Mon May 17 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 5.2.2-1mdv2010.1
+ Revision: 545046
- Patch15: incerase java heap memory size
- enable build documentation, source 2 and 3 are not needed now (mdvbz #57481)
- nuke rpath from binaries
- get rid of empty directories and files with licenses
- fix jgraphx version compare logic in cofigure script
- add buildconflicts on junit
- use enable-relocatable
- Patch14: fix build against java-hdf
- add buildrequires on hdf5-devel
- enable hdf5 support for mdv release greater than 2010.0 (mdvbz #57308)
- update to new version 5.2.2
- diable patches 5 and 6 (not needed anymore)

* Sun Jan 31 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 5.2.0-1mdv2010.1
+ Revision: 498894
- add buildconflicts on termcap-devel
- add buildrequires on jakarta-commons-beanutils and antlr
- add requires on jgraphx and jlatexmath
- rediff patches 5 and 6
- disable patches 7 and 10 (probably not needed anymore)
- nuke rpath
- update to new version 5.2.0

* Sun Sep 27 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 5.1.1-2mdv2010.0
+ Revision: 449910
- final rebuild

* Sun Jun 21 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 5.1.1-1mdv2010.0
+ Revision: 387632
- add buildrequires on xml-commons-jaxp-1.3-apis
- use mandriva specific name of xml-commons-jaxp-1.3-apis-ext jar file
- remove GiwsException files, workaround
- update to new version 5.1.1

* Wed Mar 04 2009 Paulo Andrade <pcpa@mandriva.com.br> 5.1-3mdv2009.1
+ Revision: 348617
- Update patch based on upstream correction to the libxml2
  problem. Only difference in this patch is that it doesn't call
  xmlCleanupParser() in modules/core/src/c/TerminateCore.c
  (it is already exiting), and also removes the call in
  modules/localization/src/c/loadhashtableslocalization.c

* Tue Mar 03 2009 Paulo Andrade <pcpa@mandriva.com.br> 5.1-2mdv2009.1
+ Revision: 348171
- Don't call xmlCleanupParser() if not done using libxml. It appears the
  call was done to "pair" with the call to xmlParseFile(filename_xml_conf),
  what is wrong, as xmlCleanupParser() should be called (only once?) when
  it is known that libxml functions will no longer be called again.
  See also: http://mail.gnome.org/archives/xml/2003-January/msg00155.html

* Wed Feb 18 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 5.1-1mdv2009.1
+ Revision: 342618
- disable patches 8,9 and 11-13, further investigate which one need to be drop
- Patch10: rediff
- remove few hacks, not needed
- update to new version 5.1

* Wed Feb 11 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-12mdv2009.1
+ Revision: 339352
- Patch10: add one more fix against tcl-8.6

* Tue Dec 16 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-11mdv2009.1
+ Revision: 314959
- disable -Werror=format-security cflag for now, need time and effort to fix all issues caused by this
- Patch13: correct LD_LIBRARY_PATH

* Sun Dec 14 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-10mdv2009.1
+ Revision: 314342
- Patch12: link against libfftw3.so.3
- add fonts, and help jar files
- correct patch for loading java *.so libraries
- install xml help files
- add requires on libmatio, libumfpack, swig, giws, sablotron and docbook-style-xsl

* Sat Dec 13 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-9mdv2009.1
+ Revision: 313929
- add requires on fop, saxon, batik and jeuclid-core

* Sat Dec 13 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-8mdv2009.1
+ Revision: 313862
- add requires on fftw
- Patch11: add path to mdv jre
- get rid of duplicated shlashes for java modules path

* Sat Dec 06 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-7mdv2009.1
+ Revision: 311170
- do not directly require libblas.so.3, as there are two libraries which provides this
- somehow requires on xerces-j2 was removed

* Fri Dec 05 2008 Adam Williamson <awilliamson@mandriva.org> 5.0.3-6mdv2009.1
+ Revision: 310838
- add tcl86.patch: kludge build for tcl 8.6

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - use verionate requires on java

* Wed Dec 03 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-5mdv2009.1
+ Revision: 309814
- add requires on libblas and liblapack
- add requires on xerces-j2

* Tue Dec 02 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-4mdv2009.1
+ Revision: 309497
- Patch9: fix build for latest jeuclid-core (from upstream svn)
- enable build help, since jeuclid-core is in repos
- Patch8: find jeuclid-core jar file
- fix categories in desktop file
- do not require pvm

* Tue Dec 02 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-3mdv2009.1
+ Revision: 309379
- rebuild for umfpack and amd libraries

* Sat Nov 22 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-2mdv2009.1
+ Revision: 305916
- disable build help, as it needs updated maven2
- add buildrequires on python-libxml2
- regenerate C/C++ => Java wrappers produces by giws
- enable building of help and all the docs
- add missing buildrequires on docbook-style-xsl, batik, saxon, fop
- Patch7: fix detectin of batik jar file
- regenerate Java => C wrappers produces by Swig
- use macro for configure script (thanks to Nicolas Vigier for providing a hack)
- add missing buildrequires on swig, nvurses-devel and pcre-devel
- drop not needed buildrequires
- use _disable_ld_no_undefined and _disable_ld_as_needed

* Thu Nov 20 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-1mdv2009.1
+ Revision: 305346
- license has changed to CeCILL, which is compiliant with GPL
- don't use macr for configure script, as it breaks compilation
- introduce devel subpackage
- fix file list
- remove hopefully useless hacks form spec file
- spec file clean
- adjust requires on java stuff
- add buildrequires on matio-devel
- disable ld no udefined(lot of missing links)
- add buildrequires on javahelp2, gluegen and jrosetta
- Patch: fix detection of jhall (javahelp2)
- Patch5: fix detecting of jgoodies-looks
- add buildrequires on jogl and umfpack-devel
- spec file clean
- add buildrequires on jgoodies-looks and flexdock
- export JAVA_HOME
- update to new version 5.0.3
- add missing buildrequires on blas-devel, lapack-devel, fftw3-devel, java-rpmbuild, ant
- disable all patches

* Wed Aug 06 2008 Paulo Andrade <pcpa@mandriva.com.br> 4.1.2-9mdv2009.0
+ Revision: 264889
- Force install directory to %%{_libdir}/%%{name}-%%{version}, for
  coherence. But the package should conflict with, possibly installed,
  32 binaries on x86_64.
- Always explicitly state tcl/tk libraries path (only "really" required
  when %%_libdir != /usr/lib) and properly specify pvm library path.
- Correct (not logged in last commit) change to also build on
  64 bit architectures.
- Fix #40910 scilab crashed when trying export graph
  Explicitly link with Xaw7, so it doesn't depend on Xprint
  Also, besides fixing #40910, add a better layout and correct some
  problems in the export list that would not display all alternatives.

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Tue Apr 22 2008 Paulo Andrade <pcpa@mandriva.com.br> 4.1.2-5mdv2009.0
+ Revision: 196684
+ rebuild (emptylog)

* Tue Apr 22 2008 Paulo Andrade <pcpa@mandriva.com.br> 4.1.2-4mdv2009.0
+ Revision: 196644
+ rebuild (emptylog)

* Tue Apr 22 2008 Paulo Andrade <pcpa@mandriva.com.br> 4.1.2-3mdv2009.0
+ Revision: 196636
- Correct a problem where scilab's scipad would not work correctly
  if a configuration file did not already exist in the user's home
  directory, and a problem where scipad would try to link with files
  from devel packages, printing unnecessary warning messages.

* Thu Jan 31 2008 Paulo Andrade <pcpa@mandriva.com.br> 4.1.2-2mdv2008.1
+ Revision: 160802
- Update to compile in cooker and change to use gfortran instead of g77.

  + Thierry Vignaud <tv@mandriva.org>
    - drop old menu
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Fri Oct 26 2007 Paulo Andrade <pcpa@mandriva.com.br> 4.1.2-1mdv2008.1
+ Revision: 102397
- Oops, messed in previous commit and added requires to atlas, that should have been removed.
- Update to version 4.1.2, fix Tk 8.5 dependency and add ocaml dependency.
  Minor cosmetic changes to Xaw file dialog.

* Fri Sep 28 2007 Olivier Blin <oblin@mandriva.com> 4.1.1-1mdv2008.0
+ Revision: 93801
- build on ix86 only (x86_64 build fails because configure does not
  look for tcl and tk libraries in lib64, and use g77 with invalid
  -march=athlon64 option)

  + Paulo Andrade <pcpa@mandriva.com.br>
    - Requires tcl >= 8.5. Hopefully this should fix the build problems.
    - After some "fighting" with java/ocaml support to try to add support for either
      gtk or gtk2 I give up and just add BuildRequires to xaw-devel, due to all kinds
      of errors of either duplicated or missing symbols.
    - import scilab


